Coverage for /root/GitHubProjects/impacket/impacket/version.py: 60%

# Coverage for /root/GitHubProjects/impacket/impacket/version.py : 60%

## 10 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# SECUREAUTH LABS. Copyright 2019 SecureAuth Corporation. All rights reserved.

2#

3# This software is provided under under a slightly modified version

4# of the Apache Software License. See the accompanying LICENSE file

5# for more information.

6#

7 import pkg_resources

8 from impacket import __path__

9

10

11 try:

12 version = pkg_resources.get_distribution('impacket').version

13 except pkg_resources.DistributionNotFound:

14 version = "?"

15 print("Cannot determine Impacket version. "

16 "If running from source you should at least run \"python setup.py egg_info\"")

17 BANNER = "Impacket v{} - Copyright 2020 SecureAuth Corporation\n".format(version)

18

19 def getInstallationPath():

20 return 'Impacket Library Installation Path: {}'.format(__path__[0])